Crate shoal_derive

Crate shoal_derive 

Derive Macros

ShoalDB
Derive the basic traits and functions for a type to be a table in shoal
ShoalTable
Derive the basic traits and functions for a type to be a table in shoal